within ;
model RPfr2d1
  import Modelica.SIunits.*;
  import Modelica.Constants.pi;
  parameter Mass m = 1.5;
  parameter Length l = 1;
  parameter RotationalDampingConstant k = 0.9;
  parameter Angle phi0 = pi/4;
  parameter AngularVelocity om0 = 15;

  ArgesimLib.Rope2D rope2D1(l=l, Fbrake=100000)
    annotation (Placement(transformation(extent={{-42,4},{-22,28}})));
  inner PlanarMechanics.PlanarWorld planarWorld
    annotation (Placement(transformation(extent={{-76,54},{-56,74}})));
  PlanarMechanics.Parts.Fixed fixed annotation (Placement(transformation(
        extent={{10,-10},{-10,10}},
        rotation=-90,
        origin={-32,70})));
  PlanarMechanics.Parts.Body body(     m=m, sphereDiameter=0.2,
    I=0)                                                        annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={-32,-16})));
  ArgesimLib.Revolute2D revolute2D(
    b=k,
    theta0=phi0,
    om0=om0)                       annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=-90,
        origin={-32,46})));
  ArgesimLib.RPTrigger rPTrigger
    annotation (Placement(transformation(extent={{-68,-2},{-50,16}})));
  ArgesimLib.RPStop rPStop
    annotation (Placement(transformation(extent={{-12,30},{8,50}})));
equation
  connect(fixed.frame, revolute2D.frame_a) annotation (Line(
      points={{-32,60},{-32,56}},
      color={95,95,95},
      thickness=0.5));
  connect(rope2D1.frame_a, revolute2D.frame_b) annotation (Line(
      points={{-32,28},{-32,36}},
      color={95,95,95},
      thickness=0.5));
  connect(rope2D1.frame_b, body.frame_a) annotation (Line(
      points={{-32,4},{-32,-6}},
      color={95,95,95},
      thickness=0.5));
  connect(rope2D1.s, rPTrigger.s) annotation (Line(points={{-42.2,18.4},{-72,
          18.4},{-72,12.4},{-68,12.4}},
                              color={0,0,127}));
  connect(revolute2D.flange_b, rPStop.flange_a) annotation (Line(points={{-22,40},
          {-18,40},{-18,40},{-12,40}},    color={0,0,0}));
  connect(rPTrigger.isFalling, rope2D1.isFalling) annotation (Line(points={{-50,7},
          {-46,7},{-46,6.4},{-41.8,6.4}},            color={255,0,255}));
  connect(rope2D1.f, rPTrigger.F) annotation (Line(points={{-42.2,23.2},{-74,
          23.2},{-74,1.6},{-68,1.6}},    color={0,0,127}));
  annotation (
    Icon(coordinateSystem(preserveAspectRatio=false)),
    Diagram(coordinateSystem(preserveAspectRatio=false)),
    uses(PlanarMechanics(version="1.4.0"), Modelica(version="3.2.2")),
    experiment(
      StopTime=10,
      __Dymola_NumberOfIntervals=2000,
      Tolerance=1e-10));
end RPfr2d1;
